# Generated by Django 4.2.23 on 2025-08-27 11:39

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('aa_bb', '0064_alter_complianceticket_reason'),
    ]

    operations = [
        migrations.AlterField(
            model_name='complianceticket',
            name='reason',
            field=models.CharField(choices=[('corp_check', 'Corp Compliance'), ('lawn_check', 'LAWN Compliance'), ('paps_check', 'PAP Requirements'), ('afk_check', 'Inactivity'), ('discord_check', 'User is not on discord')], max_length=20),
        ),
        migrations.AlterField(
            model_name='complianceticket',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
    ]
