# Generated by Django 4.2.23 on 2025-08-11 10:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0036_alter_general_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='CorpStatus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corp_id', models.PositiveIntegerField(default=1)),
                ('corp_name', models.TextField(max_length=50)),
                ('has_hostile_assets', models.BooleanField(default=False)),
                ('hostile_assets', models.JSONField(blank=True, default=dict)),
                ('has_sus_contracts', models.BooleanField(default=False)),
                ('sus_contracts', models.JSONField(blank=True, default=dict)),
                ('has_sus_trans', models.BooleanField(default=False)),
                ('sus_trans', models.JSONField(blank=True, default=dict)),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Corp Status',
                'verbose_name_plural': 'Corp Statuses',
            },
        ),
    ]
