# Generated by Django 4.2.23 on 2025-08-27 13:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0066_tickettoolconfig_papcompliance'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='Category_ID',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='Role_ID',
        ),
    ]
