# Generated by Django 4.2.23 on 2025-08-21 08:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0058_papsconfig_excluded_groups_get_paps_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='papsconfig',
            name='excluded_groups_get_paps',
            field=models.BooleanField(default=False, help_text='if user is in a group which prevent other groups from giving paps, do they get 1x group paps modifier?'),
        ),
    ]
