# Generated by Django 4.2.23 on 2025-08-04 08:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0024_bigbrotherconfig_dailyschedule_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='messages',
            options={'verbose_name': 'Daily Message', 'verbose_name_plural': 'Daily Messages'},
        ),
        migrations.AlterModelOptions(
            name='optmessages1',
            options={'verbose_name': 'Opt Message 1', 'verbose_name_plural': 'Opt Messages 1'},
        ),
        migrations.AlterModelOptions(
            name='optmessages2',
            options={'verbose_name': 'Opt Message 2', 'verbose_name_plural': 'Opt Messages 2'},
        ),
        migrations.AlterModelOptions(
            name='optmessages3',
            options={'verbose_name': 'Opt Message 3', 'verbose_name_plural': 'Opt Messages 3'},
        ),
        migrations.AlterModelOptions(
            name='optmessages4',
            options={'verbose_name': 'Opt Message 4', 'verbose_name_plural': 'Opt Messages 4'},
        ),
        migrations.AlterModelOptions(
            name='optmessages5',
            options={'verbose_name': 'Opt Message 5', 'verbose_name_plural': 'Opt Messages 5'},
        ),
    ]
