# Generated by Django 4.2.20 on 2025-05-07 10:36

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0014_processedcontract_processedmail_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProcessedTransaction',
            fields=[
                ('entry_id', models.BigIntegerField(help_text="The WalletJournalEntry.entry_id that we've processed", primary_key=True, serialize=False)),
                ('processed_at', models.DateTimeField(auto_now_add=True, help_text='When we first processed this transaction')),
            ],
            options={
                'verbose_name': 'Processed Transaction',
                'verbose_name_plural': 'Processed Transactions',
                'db_table': 'aa_bb_processed_transactions',
            },
        ),
        migrations.CreateModel(
            name='SusTransactionNote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user_id', models.BigIntegerField(help_text='The AllianceAuth user ID who owns these characters')),
                ('note', models.TextField(help_text='The summary string of flags for this transaction')),
                ('created', models.DateTimeField(auto_now_add=True, help_text='When this note was created')),
                ('updated', models.DateTimeField(auto_now=True, help_text='When this note was last updated')),
                ('transaction', models.OneToOneField(help_text='The transaction this note refers to', on_delete=django.db.models.deletion.CASCADE, to='aa_bb.processedtransaction')),
            ],
            options={
                'verbose_name': 'Suspicious Transaction Note',
                'verbose_name_plural': 'Suspicious Transaction Notes',
                'db_table': 'aa_bb_sus_transaction_notes',
            },
        ),
    ]
