# Generated by Django 4.2.23 on 2025-08-08 10:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0033_messagetype_bigbrotherconfig_pingroleid2_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userstatus',
            old_name='last_updated',
            new_name='updated',
        ),
    ]
