# Generated by Django 4.2.21 on 2025-05-31 12:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0017_entityinfocache'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstatus',
            name='cyno',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='has_skills',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='skills',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
