# Generated by Django 4.2.23 on 2026-01-05 19:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0101_userstatus_compliance_forum_thread_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='use_forum_threads',
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_inactivity_days',
            field=models.PositiveIntegerField(default=30, help_text='Number of days of Discord inactivity before a ticket is created.'),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_inactivity_enabled',
            field=models.BooleanField(default=False, help_text="If enabled, a ticket will be created if a user hasn't sent a message on Discord for a certain number of days."),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='discord_inactivity_reason',
            field=models.TextField(blank=True, default='<@&{role}>,<@{namee}>, you have been inactive on Discord for over {days} day(s), please fix it.', help_text='Message to send with {role}, {namee} and {days} variables', null=True),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='last_discord_message_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='complianceticket',
            name='reason',
            field=models.CharField(choices=[('corp_check', 'Corp Compliance'), ('paps_check', 'PAP Requirements'), ('afk_check', 'Inactivity'), ('discord_check', 'User is not on discord'), ('char_removed', 'Character removed'), ('awox_kill', 'AWOX kill found'), ('discord_inactivity', 'Discord Inactivity')], max_length=20),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='Forum_Channel_ID',
            field=models.PositiveBigIntegerField(blank=True, default=0, help_text='Channel ID to create threads in (for Bot-managed threads)', null=True, verbose_name='Channel/Thread ID'),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='afk_check_enabled',
            field=models.BooleanField(default=False, help_text="If enabled, checks if any character on the user's account has logged into the game within the allowed timeframe."),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='corp_check_enabled',
            field=models.BooleanField(default=False, help_text="If enabled, checks if all of a user's characters have the required ESI tokens for the corporation compliance filter."),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='discord_check_enabled',
            field=models.BooleanField(default=False, help_text='If enabled, checks if the user has a Discord account linked to their Alliance Auth profile.'),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='paps_check_enabled',
            field=models.BooleanField(default=False, help_text='If enabled, checks if the user has met the minimum PAP requirements (Integration with aa-afat).'),
        ),
    ]
