# Generated by Django 4.2.23 on 2025-08-16 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0024_alter_userprofile_language'),
        ('aa_bb', '0042_alter_general_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='bb_member_states',
            field=models.ManyToManyField(blank=True, help_text='List of states to be considered members', related_name='bb_member_states_configs', to='authentication.state'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='bb_guest_states',
            field=models.ManyToManyField(blank=True, help_text='List of states to be considered guests', related_name='bb_guest_states_configs', to='authentication.state'),
        ),
    ]
