# Generated by Django 4.2.23 on 2025-10-30 21:43

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0075_bbupdatestate_tickettoolconfig_afk_check_frequency_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='id_types',
            name='last_accessed',
            field=models.DateTimeField(default=django.utils.timezone.now, help_text='When this record was last looked up'),
        ),
        migrations.CreateModel(
            name='FrequentCorpChangesCache',
            fields=[
                ('user_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('html', models.TextField()),
                ('updated', models.DateTimeField(auto_now=True)),
                ('last_accessed', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'db_table': 'frequent_corp_changes_cache',
                'indexes': [models.Index(fields=['updated'], name='frequent_co_updated_43ba09_idx'), models.Index(fields=['last_accessed'], name='frequent_co_last_ac_bfcec4_idx')],
            },
        ),
        migrations.CreateModel(
            name='CurrentStintCache',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('char_id', models.BigIntegerField()),
                ('corp_id', models.BigIntegerField()),
                ('days', models.IntegerField(default=0)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('last_accessed', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'db_table': 'current_stint_cache',
                'indexes': [models.Index(fields=['char_id', 'corp_id'], name='current_sti_char_id_0bbf63_idx'), models.Index(fields=['updated'], name='current_sti_updated_28b144_idx'), models.Index(fields=['last_accessed'], name='current_sti_last_ac_f56fae_idx')],
                'unique_together': {('char_id', 'corp_id')},
            },
        ),
        migrations.CreateModel(
            name='CharacterEmploymentCache',
            fields=[
                ('char_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('data', models.JSONField()),
                ('updated', models.DateTimeField(auto_now=True)),
                ('last_accessed', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'db_table': 'character_employment_cache',
                'indexes': [models.Index(fields=['updated'], name='character_e_updated_40b6bb_idx'), models.Index(fields=['last_accessed'], name='character_e_last_ac_44a363_idx')],
            },
        ),
        migrations.CreateModel(
            name='AwoxKillsCache',
            fields=[
                ('user_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('data', models.JSONField()),
                ('updated', models.DateTimeField(auto_now=True)),
                ('last_accessed', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'db_table': 'awox_kills_cache',
                'indexes': [models.Index(fields=['updated'], name='awox_kills__updated_d44021_idx'), models.Index(fields=['last_accessed'], name='awox_kills__last_ac_0e466a_idx')],
            },
        ),
    ]
