# Generated by Django 4.2.23 on 2025-08-16 17:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0044_bigbrotherconfig_character_scopes_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstatus',
            name='sp_age_ratio_result',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
