<!--
  PAP-specific navbar links controlled by the viewer's permissions.
-->
{% load i18n %}
{% if perms.aa_bb.can_access_paps %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'paps:history' %}">
            <i class="fas fa-chart-bar"></i>
            <span class="d-md-inline m-2">{% translate "PAP Stats" %}</span>
        </a>
    </li>
{% endif %}
{% if perms.aa_bb.can_generate_paps %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'paps:index' %}">
            <i class="fas fa-cogs"></i>
            <span class="d-md-inline m-2">{% translate "Generate Chart" %}</span>
        </a>
    </li>
{% endif %}
