# Generated by Django 4.2.20 on 2025-04-21 10:03

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('aa_bb', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BigBrotherConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(help_text='Input the token you were provided to install this app', max_length=255)),
                ('pingroleID', models.CharField(default=None, help_text='Input the role ID you want pinged when people need to investigate', max_length=255)),
                ('hostile_alliances', models.TextField(blank=True, help_text="List of alliance IDs considered hostile, separated by ','", null=True)),
                ('hostile_corporations', models.TextField(blank=True, help_text="List of corporation IDs considered hostile, separated by ','", null=True)),
                ('webhook', models.URLField(blank=True, help_text='Discord webhook for sending notifications', null=True)),
                ('main_corporation_id', models.BigIntegerField(default=0, editable=False, help_text='Your Corporation Id')),
                ('main_corporation', models.TextField(default=0, editable=False, help_text='Your Corporation')),
                ('main_alliance_id', models.PositiveIntegerField(default=123456789, editable=False, help_text='Your alliance ID')),
                ('main_alliance', models.TextField(default=123456789, editable=False, help_text='Your alliance')),
                ('is_active', models.BooleanField(default=True, editable=False, help_text='has the plugin been activated/deactivated?')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='UserStatus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('has_awox_kills', models.BooleanField(default=False)),
                ('awox_kill_links', models.JSONField(blank=True, default=list)),
                ('has_cyno', models.BooleanField(default=False)),
                ('has_hostile_assets', models.BooleanField(default=False)),
                ('hostile_assets', models.JSONField(blank=True, default=list)),
                ('has_hostile_clones', models.BooleanField(default=False)),
                ('hostile_clones', models.JSONField(blank=True, default=list)),
                ('has_imp_blacklist', models.BooleanField(default=False)),
                ('has_lawn_blacklist', models.BooleanField(default=False)),
                ('has_game_time_notifications', models.BooleanField(default=False)),
                ('has_skill_injected', models.BooleanField(default=False)),
                ('has_sus_contacts', models.BooleanField(default=False)),
                ('has_sus_contracts', models.BooleanField(default=False)),
                ('has_sus_mails', models.BooleanField(default=False)),
                ('has_sus_trans', models.BooleanField(default=False)),
                ('last_updated', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
