# Generated by Django 4.2.23 on 2025-09-02 12:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0072_alter_complianceticket_reason'),
    ]

    operations = [
        migrations.AddField(
            model_name='tickettoolconfig',
            name='starting_pap_compliance',
            field=models.PositiveIntegerField(default=1, help_text='How many buffer months does a new user get? (starter value of the above)'),
        ),
    ]
