# Generated by Django 4.2.21 on 2025-12-28 15:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0097_bigbrotherconfig_hostile_everyone_else'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='exclude_high_sec',
            field=models.BooleanField(default=False, help_text='If enabled, activities in High-Sec (security 0.5 to 1.0) will be ignored.', verbose_name='Exclude High-Sec'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='exclude_low_sec',
            field=models.BooleanField(default=False, help_text='If enabled, activities in Low-Sec (security 0.01 to 0.49) will be ignored.', verbose_name='Exclude Low-Sec'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='loawebhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending Leave of Absence', null=True, verbose_name='Leave of Absence Discord WebHook'),
        ),
    ]
