# Generated by Django 4.2.21 on 2026-01-12 19:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0108_bigbrotherconfig_exclude_neutral_contacts'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='discord_check_reason',
            field=models.TextField(blank=True, default="<@&{role}>,**{namee}**, doesn't have their discord linked on corp auth, try to contact them and if unable, kick them out", help_text='Message to send with {role} and {namee} variables', null=True),
        ),
        migrations.AlterField(
            model_name='tickettoolconfig',
            name='discord_check_reminder',
            field=models.TextField(blank=True, default="<@&{role}>,**{namee}**'s compliance issue is still unresolved, try to contact them and if unable within {days} day(s) kick them out.", help_text='Message to send with {role}, {namee} and {days} variables', null=True),
        ),
    ]
