# Generated by Django 4.2.21 on 2025-08-03 12:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0019_bigbrotherconfig_whitelist_alliances_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Messages',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('text', models.CharField(max_length=2000)),
            ],
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='are_daily_messages_active',
            field=models.BooleanField(default=False, help_text='are daily messages activated/deactivated?'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='dailywebhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending daily messages', null=True),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending BB notifications', null=True),
        ),
    ]
