# Generated by Django 4.2.23 on 2025-08-08 12:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0034_rename_last_updated_userstatus_updated'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userstatus',
            options={'verbose_name': 'User Status', 'verbose_name_plural': 'User Statuses'},
        ),
    ]
