# Generated by Django 4.2.23 on 2025-08-20 11:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0051_monthlypapstats'),
    ]

    operations = [
        migrations.CreateModel(
            name='PapsConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('required_paps', models.PositiveIntegerField(default=1, editable=False, help_text='How many PAPs per month should a user get?')),
                ('corp_modifier', models.PositiveIntegerField(default=1, editable=False, help_text='How many PAPs is a corp PAP worth?')),
                ('max_corp_paps', models.PositiveIntegerField(default=1, editable=False, help_text='How many Corp PAPs will count?')),
                ('lawn_modifier', models.PositiveIntegerField(default=1, editable=False, help_text='How many PAPs is a lawn PAP worth?')),
                ('imp_modifier', models.PositiveIntegerField(default=1, editable=False, help_text='How many PAPs is an imp PAP worth?')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.DeleteModel(
            name='MonthlyPapStats',
        ),
    ]
