# Generated by Django 4.2.23 on 2025-08-20 15:35

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('aa_bb', '0056_alter_papsconfig_group_paps'),
    ]

    operations = [
        migrations.AddField(
            model_name='papsconfig',
            name='excluded_groups',
            field=models.ManyToManyField(blank=True, help_text='List of groups which prevent giving paps', related_name='excluded_groups', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='excluded_users',
            field=models.ManyToManyField(blank=True, help_text='List of user prevented from getting paps from groups', related_name='excluded_user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='papsconfig',
            name='group_paps',
            field=models.ManyToManyField(blank=True, help_text='List of groups which give paps', related_name='group_paps', to='groupmanagement.authgroup'),
        ),
    ]
