# Generated by Django 4.2.21 on 2026-01-09 00:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0106_bigbrotherconfig_consider_lowsec_hostile'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='Role_ID',
        ),
        migrations.RemoveField(
            model_name='tickettoolconfig',
            name='staff_roles',
        ),
        migrations.AddField(
            model_name='complianceticket',
            name='exception_reason',
            field=models.TextField(blank=True, help_text='Reason why this ticket was marked as an exception', null=True),
        ),
        migrations.AddField(
            model_name='complianceticket',
            name='is_exception',
            field=models.BooleanField(default=False, help_text="Ticket is marked as an exception and won't receive reminders or be recreated"),
        ),
        migrations.AddField(
            model_name='tickettoolconfig',
            name='role_id',
            field=models.TextField(blank=True, help_text='Comma-separated list of role IDs to add to ticket channels/threads'),
        ),
    ]
