# Generated by Django 4.2.20 on 2025-04-25 11:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0008_alliance_names_corporation_names'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstatus',
            name='sus_contacts',
            field=models.JSONField(blank=True, default=list),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='sus_contracts',
            field=models.JSONField(blank=True, default=list),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='sus_mails',
            field=models.JSONField(blank=True, default=list),
        ),
        migrations.AddField(
            model_name='userstatus',
            name='sus_trans',
            field=models.JSONField(blank=True, default=list),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='hostile_alliances',
            field=models.TextField(blank=True, default='1900696668,741557221,154104258,99013231,495729389,99002685,99001317,99012770,99010281,99009977,498125261,99007203,99003581,99005338,1042504553,1727758877,386292982,99011983,99012617,917526329,99009927,99006941,1411711376,99003557,99006411,98718891,99011312,99010877,99007887,99010735,99000285,99007629,1988009451,1220922756,99011990,99011416,99011268,933731581,99005874', help_text="List of alliance IDs considered hostile, separated by ','", null=True),
        ),
    ]
