# Generated by Django 4.2.21 on 2025-12-27 14:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0096_bigbrotherconfig_clone_state_notify_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='hostile_everyone_else',
            field=models.BooleanField(default=False, help_text='If enabled, any entity (character, corporation, or alliance) not explicitly on the member, white, or ignore lists will be treated as hostile.', verbose_name='Treat all unknown entities as hostile'),
        ),
    ]
