<!--
  LOA-specific nav links rendered inside the AA navbar.
  Shows request/admin entries depending on the viewer's permissions.
-->
{% load i18n %}
{% if perms.aa_bb.can_access_loa %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'loa:index' %}">
            <i class="fas fa-plane"></i>
            <span class="d-md-inline m-2">{% translate "My Requests" %}</span>
        </a>
    </li>
    <li class="nav-item">
        <a class="nav-link" href="{% url 'loa:request' %}">
            <i class="fas fa-plane"></i>
            <span class="d-md-inline m-2">{% translate "Request a Leave of Absence" %}</span>
        </a>
    </li>
{% endif %}
{% if perms.aa_bb.can_manage_loa %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'loa:admin' %}">
            <i class="fas fa-cog"></i>
            <span class="d-md-inline m-2">{% translate "LoA Admin" %}</span>
        </a>
    </li>
{% endif %}
