<!--
  Base shell for the member-facing Big Brother pages.
  Provides the AA layout and exposes a `details` block that individual tabs fill.
-->
{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Big Brother" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Big Brother" %}
{% endblock header_nav_brand %}

{% block header_nav %}
    {{ block.super }}
{% endblock %}

{% block content %}
    <div class="aa_bb">
        {% block details %}{% endblock %}
    </div>
{% endblock %}
