# Generated by Django 4.2.23 on 2025-08-04 08:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_celery_beat', '0019_alter_periodictasks_options'),
        ('aa_bb', '0023_optmessages1_optmessages2_optmessages3_optmessages4_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='dailyschedule',
            field=models.ForeignKey(blank=True, help_text='schedule for daily messages', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_dailyschedule', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule1',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 1', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule1', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule2',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 2', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule2', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule3',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 3', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule3', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule4',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 4', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule4', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule5',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 5', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule5', to='django_celery_beat.crontabschedule'),
        ),
    ]
