# Generated by Django 4.2.23 on 2025-12-12 23:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0088_bigbrotherconfig_cyno_notify'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='asset_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Asset Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='clone_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Clone State Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contact_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contact Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contract_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contract Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='mail_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Mail notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='new_user_notify',
            field=models.BooleanField(default=False, help_text='Whether to send notifications of all previous user history when a user first gets audited, this can be VERY spammy on a first time load of the tool'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='sp_inject_notify',
            field=models.BooleanField(default=True, help_text='Whether to send SP Injection notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='transaction_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Transaction notifications to discord'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='cyno_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Cyno Change notifications to discord'),
        ),
    ]
