<!--
  Simple splash page for when Corp Brother is intentionally disabled.
  Reuses the base layout but replaces the dashboard cards with a static alert.
-->
{% extends 'aa_cb/base.html' %}
{% load i18n %}
{% load humanize %}

{% block details %}

<!-- Error / Info Message -->
<div id="messageBox" class="alert alert-danger">
    Corp Brother is currently in an inactive state, please make sure it is up to date, you have filled the settings and turned on the task.
    </div>

{% endblock %}

{% block extra_javascript %}

{% endblock %}
