# Generated by Django 4.2.23 on 2025-08-26 09:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('aa_bb', '0060_papsconfig_cap_group_papsconfig_cap_group_paps_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='papsconfig',
            name='cap_group',
        ),
        migrations.RemoveField(
            model_name='papsconfig',
            name='super_group',
        ),
        migrations.RemoveField(
            model_name='papsconfig',
            name='titan_group',
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='cap_group',
            field=models.ForeignKey(blank=True, help_text='Select your cap group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='cap_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='super_group',
            field=models.ForeignKey(blank=True, help_text='Select your super group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='super_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='titan_group',
            field=models.ForeignKey(blank=True, help_text='Select your titan group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='titan_group', to='groupmanagement.authgroup'),
        ),
    ]
